# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/MVSControl.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct

import digitaleye_msgs.msg
import std_msgs.msg

class MVSControl(genpy.Message):
  _md5sum = "1c4d104de8a94e102bf6b92a997a16ce"
  _type = "digitaleye_msgs/MVSControl"
  _has_header = True  # flag to mark the presence of a Header object
  _full_text = """# Description TODO

std_msgs/Header header
digitaleye_msgs/Metric[] parameters

================================================================================
MSG: std_msgs/Header
# Standard metadata for higher-level stamped data types.
# This is generally used to communicate timestamped data 
# in a particular coordinate frame.
# 
# sequence ID: consecutively increasing ID 
uint32 seq
#Two-integer timestamp that is expressed as:
# * stamp.sec: seconds (stamp_secs) since epoch (in Python the variable is called 'secs')
# * stamp.nsec: nanoseconds since stamp_secs (in Python the variable is called 'nsecs')
# time-handling sugar is provided by the client library
time stamp
#Frame this data is associated with
string frame_id

================================================================================
MSG: digitaleye_msgs/Metric
# Performance indicator for a subsystem,
# component or sensor

# name of the performance indicator
string name

# value of the performance indicator
string value
"""
  __slots__ = ['header','parameters']
  _slot_types = ['std_msgs/Header','digitaleye_msgs/Metric[]']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       header,parameters

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(MVSControl, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.header is None:
        self.header = std_msgs.msg.Header()
      if self.parameters is None:
        self.parameters = []
    else:
      self.header = std_msgs.msg.Header()
      self.parameters = []

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      _x = self
      buff.write(_get_struct_3I().pack(_x.header.seq, _x.header.stamp.secs, _x.header.stamp.nsecs))
      _x = self.header.frame_id
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      length = len(self.parameters)
      buff.write(_struct_I.pack(length))
      for val1 in self.parameters:
        _x = val1.name
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        _x = val1.value
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.header is None:
        self.header = std_msgs.msg.Header()
      if self.parameters is None:
        self.parameters = None
      end = 0
      _x = self
      start = end
      end += 12
      (_x.header.seq, _x.header.stamp.secs, _x.header.stamp.nsecs,) = _get_struct_3I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.header.frame_id = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.header.frame_id = str[start:end]
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.parameters = []
      for i in range(0, length):
        val1 = digitaleye_msgs.msg.Metric()
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          val1.name = str[start:end].decode('utf-8', 'rosmsg')
        else:
          val1.name = str[start:end]
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          val1.value = str[start:end].decode('utf-8', 'rosmsg')
        else:
          val1.value = str[start:end]
        self.parameters.append(val1)
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      _x = self
      buff.write(_get_struct_3I().pack(_x.header.seq, _x.header.stamp.secs, _x.header.stamp.nsecs))
      _x = self.header.frame_id
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      length = len(self.parameters)
      buff.write(_struct_I.pack(length))
      for val1 in self.parameters:
        _x = val1.name
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        _x = val1.value
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.header is None:
        self.header = std_msgs.msg.Header()
      if self.parameters is None:
        self.parameters = None
      end = 0
      _x = self
      start = end
      end += 12
      (_x.header.seq, _x.header.stamp.secs, _x.header.stamp.nsecs,) = _get_struct_3I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.header.frame_id = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.header.frame_id = str[start:end]
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.parameters = []
      for i in range(0, length):
        val1 = digitaleye_msgs.msg.Metric()
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          val1.name = str[start:end].decode('utf-8', 'rosmsg')
        else:
          val1.name = str[start:end]
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          val1.value = str[start:end].decode('utf-8', 'rosmsg')
        else:
          val1.value = str[start:end]
        self.parameters.append(val1)
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
_struct_3I = None
def _get_struct_3I():
    global _struct_3I
    if _struct_3I is None:
        _struct_3I = struct.Struct("<3I")
    return _struct_3I



# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/GetStatusRequest.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct


class GetStatusRequest(genpy.Message):
  _md5sum = "d41d8cd98f00b204e9800998ecf8427e"
  _type = "digitaleye_msgs/GetStatusRequest"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """"""
  __slots__ = []
  _slot_types = []

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(GetStatusRequest, self).__init__(*args, **kwds)

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      pass
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      end = 0
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      pass
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      end = 0
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/GetStatusResponse.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct

import digitaleye_msgs.msg
import geometry_msgs.msg
import sensor_msgs.msg
import std_msgs.msg

class GetStatusResponse(genpy.Message):
  _md5sum = "3debe849e7d84e1c8a45738e73fc747e"
  _type = "digitaleye_msgs/GetStatusResponse"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """# DigitalEye Operating Status
digitaleye_msgs/DigitalEyeStatus status


================================================================================
MSG: digitaleye_msgs/DigitalEyeStatus
# Details of the DigitalEye’s external state,
# and the states of its subsystems

# TODO
uint32 started

# current external state of the DigitalEye
digitaleye_msgs/State digitaleye

# states of the DigitalEye’s subsystem(s)
# (DEMS, MVS , IOT, etc.) and their component(s)
digitaleye_msgs/SystemState[] subsystems

================================================================================
MSG: digitaleye_msgs/State
# Details of a system’s status

# unique identifier of the system
# whose status is being reported
uint32 id

# system’s current state within the 
# DigitalEye state machine
uint32 state

# system’s substatus within the current state,
# unique to each system
uint32 status

# description of the system’s current state/status
string description

# timestamp indicating last change in state or status
# (epoch time in sec)
uint32 lastChange

# list of performance metrics associated with the
# current state
digitaleye_msgs/Metric[] metrics

================================================================================
MSG: digitaleye_msgs/Metric
# Performance indicator for a subsystem,
# component or sensor

# name of the performance indicator
string name

# value of the performance indicator
string value

================================================================================
MSG: digitaleye_msgs/SystemState
# State of a system and its constituent subsystem(s)

# state of the system
digitaleye_msgs/State system

# list of the state(s) of the system’s constituent component(s)
digitaleye_msgs/ComponentState[] components

================================================================================
MSG: digitaleye_msgs/ComponentState
# State of a system component and its attached sensor(s)

# state of the component
digitaleye_msgs/State component

# state(s) of the component’s attached sensor(s)
digitaleye_msgs/Sensor[] sensors

================================================================================
MSG: digitaleye_msgs/Sensor
# Description of a monitoring DigitalEye sensor
# and its properties

# unique identifier of the sensor
# e.g. hardware serial number
string sensor_id

# brand/model of sensor hardware
string model

# type of sensor being described
# e.g. camera, LIDAR, etc.
uint32 type

# position of the sensor in
# the DigitalEye’s local reference frame (meters)
geometry_msgs/Pose pose

# direction in which the sensor is facing
# with respect to the local frame’s x-axis
float32 azimuth

# resolution height of the image captured by the sensor
uint32 image_width

# resolution width of the image captured by the sensor
uint32 image_height

# frame rate of a vision sensor
uint32 frame_rate

# sensor’s current power level
float32 power

# Whether or not the sensor has been calibrated
bool calibrated

# current state of the sensor
digitaleye_msgs/State state

# Sensor inertial measurements
digitaleye_msgs/IMUValue imu

================================================================================
MSG: geometry_msgs/Pose
# A representation of pose in free space, composed of position and orientation. 
Point position
Quaternion orientation

================================================================================
MSG: geometry_msgs/Point
# This contains the position of a point in free space
float64 x
float64 y
float64 z

================================================================================
MSG: geometry_msgs/Quaternion
# This represents an orientation in free space in quaternion form.

float64 x
float64 y
float64 z
float64 w

================================================================================
MSG: digitaleye_msgs/IMUValue
# Description of an IMU value reading

# Imu heading
float32 heading

# Unique identifier of the sensor
# e.g. hardware serial number
string device_id

# Imu measurements
sensor_msgs/Imu imu

# Magenetometer readings
geometry_msgs/Vector3 magnetic_field

# Imu reading of roll
float32 roll

# Imu reading of pitch
float32 pitch

# Calibration status
bool deviceCalibrated

================================================================================
MSG: sensor_msgs/Imu
# This is a message to hold data from an IMU (Inertial Measurement Unit)
#
# Accelerations should be in m/s^2 (not in g's), and rotational velocity should be in rad/sec
#
# If the covariance of the measurement is known, it should be filled in (if all you know is the 
# variance of each measurement, e.g. from the datasheet, just put those along the diagonal)
# A covariance matrix of all zeros will be interpreted as "covariance unknown", and to use the
# data a covariance will have to be assumed or gotten from some other source
#
# If you have no estimate for one of the data elements (e.g. your IMU doesn't produce an orientation 
# estimate), please set element 0 of the associated covariance matrix to -1
# If you are interpreting this message, please check for a value of -1 in the first element of each 
# covariance matrix, and disregard the associated estimate.

Header header

geometry_msgs/Quaternion orientation
float64[9] orientation_covariance # Row major about x, y, z axes

geometry_msgs/Vector3 angular_velocity
float64[9] angular_velocity_covariance # Row major about x, y, z axes

geometry_msgs/Vector3 linear_acceleration
float64[9] linear_acceleration_covariance # Row major x, y z 

================================================================================
MSG: std_msgs/Header
# Standard metadata for higher-level stamped data types.
# This is generally used to communicate timestamped data 
# in a particular coordinate frame.
# 
# sequence ID: consecutively increasing ID 
uint32 seq
#Two-integer timestamp that is expressed as:
# * stamp.sec: seconds (stamp_secs) since epoch (in Python the variable is called 'secs')
# * stamp.nsec: nanoseconds since stamp_secs (in Python the variable is called 'nsecs')
# time-handling sugar is provided by the client library
time stamp
#Frame this data is associated with
string frame_id

================================================================================
MSG: geometry_msgs/Vector3
# This represents a vector in free space. 
# It is only meant to represent a direction. Therefore, it does not
# make sense to apply a translation to it (e.g., when applying a 
# generic rigid transformation to a Vector3, tf2 will only apply the
# rotation). If you want your data to be translatable too, use the
# geometry_msgs/Point message instead.

float64 x
float64 y
float64 z"""
  __slots__ = ['status']
  _slot_types = ['digitaleye_msgs/DigitalEyeStatus']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       status

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(GetStatusResponse, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.status is None:
        self.status = digitaleye_msgs.msg.DigitalEyeStatus()
    else:
      self.status = digitaleye_msgs.msg.DigitalEyeStatus()

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      _x = self
      buff.write(_get_struct_4I().pack(_x.status.started, _x.status.digitaleye.id, _x.status.digitaleye.state, _x.status.digitaleye.status))
      _x = self.status.digitaleye.description
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self.status.digitaleye.lastChange
      buff.write(_get_struct_I().pack(_x))
      length = len(self.status.digitaleye.metrics)
      buff.write(_struct_I.pack(length))
      for val1 in self.status.digitaleye.metrics:
        _x = val1.name
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        _x = val1.value
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      length = len(self.status.subsystems)
      buff.write(_struct_I.pack(length))
      for val1 in self.status.subsystems:
        _v1 = val1.system
        _x = _v1
        buff.write(_get_struct_3I().pack(_x.id, _x.state, _x.status))
        _x = _v1.description
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        _x = _v1.lastChange
        buff.write(_get_struct_I().pack(_x))
        length = len(_v1.metrics)
        buff.write(_struct_I.pack(length))
        for val3 in _v1.metrics:
          _x = val3.name
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _x = val3.value
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        length = len(val1.components)
        buff.write(_struct_I.pack(length))
        for val2 in val1.components:
          _v2 = val2.component
          _x = _v2
          buff.write(_get_struct_3I().pack(_x.id, _x.state, _x.status))
          _x = _v2.description
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _x = _v2.lastChange
          buff.write(_get_struct_I().pack(_x))
          length = len(_v2.metrics)
          buff.write(_struct_I.pack(length))
          for val4 in _v2.metrics:
            _x = val4.name
            length = len(_x)
            if python3 or type(_x) == unicode:
              _x = _x.encode('utf-8')
              length = len(_x)
            buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
            _x = val4.value
            length = len(_x)
            if python3 or type(_x) == unicode:
              _x = _x.encode('utf-8')
              length = len(_x)
            buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          length = len(val2.sensors)
          buff.write(_struct_I.pack(length))
          for val3 in val2.sensors:
            _x = val3.sensor_id
            length = len(_x)
            if python3 or type(_x) == unicode:
              _x = _x.encode('utf-8')
              length = len(_x)
            buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
            _x = val3.model
            length = len(_x)
            if python3 or type(_x) == unicode:
              _x = _x.encode('utf-8')
              length = len(_x)
            buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
            _x = val3.type
            buff.write(_get_struct_I().pack(_x))
            _v3 = val3.pose
            _v4 = _v3.position
            _x = _v4
            buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
            _v5 = _v3.orientation
            _x = _v5
            buff.write(_get_struct_4d().pack(_x.x, _x.y, _x.z, _x.w))
            _x = val3
            buff.write(_get_struct_f3IfB().pack(_x.azimuth, _x.image_width, _x.image_height, _x.frame_rate, _x.power, _x.calibrated))
            _v6 = val3.state
            _x = _v6
            buff.write(_get_struct_3I().pack(_x.id, _x.state, _x.status))
            _x = _v6.description
            length = len(_x)
            if python3 or type(_x) == unicode:
              _x = _x.encode('utf-8')
              length = len(_x)
            buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
            _x = _v6.lastChange
            buff.write(_get_struct_I().pack(_x))
            length = len(_v6.metrics)
            buff.write(_struct_I.pack(length))
            for val5 in _v6.metrics:
              _x = val5.name
              length = len(_x)
              if python3 or type(_x) == unicode:
                _x = _x.encode('utf-8')
                length = len(_x)
              buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
              _x = val5.value
              length = len(_x)
              if python3 or type(_x) == unicode:
                _x = _x.encode('utf-8')
                length = len(_x)
              buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
            _v7 = val3.imu
            _x = _v7.heading
            buff.write(_get_struct_f().pack(_x))
            _x = _v7.device_id
            length = len(_x)
            if python3 or type(_x) == unicode:
              _x = _x.encode('utf-8')
              length = len(_x)
            buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
            _v8 = _v7.imu
            _v9 = _v8.header
            _x = _v9.seq
            buff.write(_get_struct_I().pack(_x))
            _v10 = _v9.stamp
            _x = _v10
            buff.write(_get_struct_2I().pack(_x.secs, _x.nsecs))
            _x = _v9.frame_id
            length = len(_x)
            if python3 or type(_x) == unicode:
              _x = _x.encode('utf-8')
              length = len(_x)
            buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
            _v11 = _v8.orientation
            _x = _v11
            buff.write(_get_struct_4d().pack(_x.x, _x.y, _x.z, _x.w))
            buff.write(_get_struct_9d().pack(*_v8.orientation_covariance))
            _v12 = _v8.angular_velocity
            _x = _v12
            buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
            buff.write(_get_struct_9d().pack(*_v8.angular_velocity_covariance))
            _v13 = _v8.linear_acceleration
            _x = _v13
            buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
            buff.write(_get_struct_9d().pack(*_v8.linear_acceleration_covariance))
            _v14 = _v7.magnetic_field
            _x = _v14
            buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
            _x = _v7
            buff.write(_get_struct_2fB().pack(_x.roll, _x.pitch, _x.deviceCalibrated))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.status is None:
        self.status = digitaleye_msgs.msg.DigitalEyeStatus()
      end = 0
      _x = self
      start = end
      end += 16
      (_x.status.started, _x.status.digitaleye.id, _x.status.digitaleye.state, _x.status.digitaleye.status,) = _get_struct_4I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.status.digitaleye.description = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.status.digitaleye.description = str[start:end]
      start = end
      end += 4
      (self.status.digitaleye.lastChange,) = _get_struct_I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.status.digitaleye.metrics = []
      for i in range(0, length):
        val1 = digitaleye_msgs.msg.Metric()
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          val1.name = str[start:end].decode('utf-8', 'rosmsg')
        else:
          val1.name = str[start:end]
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          val1.value = str[start:end].decode('utf-8', 'rosmsg')
        else:
          val1.value = str[start:end]
        self.status.digitaleye.metrics.append(val1)
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.status.subsystems = []
      for i in range(0, length):
        val1 = digitaleye_msgs.msg.SystemState()
        _v15 = val1.system
        _x = _v15
        start = end
        end += 12
        (_x.id, _x.state, _x.status,) = _get_struct_3I().unpack(str[start:end])
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          _v15.description = str[start:end].decode('utf-8', 'rosmsg')
        else:
          _v15.description = str[start:end]
        start = end
        end += 4
        (_v15.lastChange,) = _get_struct_I().unpack(str[start:end])
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        _v15.metrics = []
        for i in range(0, length):
          val3 = digitaleye_msgs.msg.Metric()
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            val3.name = str[start:end].decode('utf-8', 'rosmsg')
          else:
            val3.name = str[start:end]
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            val3.value = str[start:end].decode('utf-8', 'rosmsg')
          else:
            val3.value = str[start:end]
          _v15.metrics.append(val3)
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        val1.components = []
        for i in range(0, length):
          val2 = digitaleye_msgs.msg.ComponentState()
          _v16 = val2.component
          _x = _v16
          start = end
          end += 12
          (_x.id, _x.state, _x.status,) = _get_struct_3I().unpack(str[start:end])
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            _v16.description = str[start:end].decode('utf-8', 'rosmsg')
          else:
            _v16.description = str[start:end]
          start = end
          end += 4
          (_v16.lastChange,) = _get_struct_I().unpack(str[start:end])
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          _v16.metrics = []
          for i in range(0, length):
            val4 = digitaleye_msgs.msg.Metric()
            start = end
            end += 4
            (length,) = _struct_I.unpack(str[start:end])
            start = end
            end += length
            if python3:
              val4.name = str[start:end].decode('utf-8', 'rosmsg')
            else:
              val4.name = str[start:end]
            start = end
            end += 4
            (length,) = _struct_I.unpack(str[start:end])
            start = end
            end += length
            if python3:
              val4.value = str[start:end].decode('utf-8', 'rosmsg')
            else:
              val4.value = str[start:end]
            _v16.metrics.append(val4)
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          val2.sensors = []
          for i in range(0, length):
            val3 = digitaleye_msgs.msg.Sensor()
            start = end
            end += 4
            (length,) = _struct_I.unpack(str[start:end])
            start = end
            end += length
            if python3:
              val3.sensor_id = str[start:end].decode('utf-8', 'rosmsg')
            else:
              val3.sensor_id = str[start:end]
            start = end
            end += 4
            (length,) = _struct_I.unpack(str[start:end])
            start = end
            end += length
            if python3:
              val3.model = str[start:end].decode('utf-8', 'rosmsg')
            else:
              val3.model = str[start:end]
            start = end
            end += 4
            (val3.type,) = _get_struct_I().unpack(str[start:end])
            _v17 = val3.pose
            _v18 = _v17.position
            _x = _v18
            start = end
            end += 24
            (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
            _v19 = _v17.orientation
            _x = _v19
            start = end
            end += 32
            (_x.x, _x.y, _x.z, _x.w,) = _get_struct_4d().unpack(str[start:end])
            _x = val3
            start = end
            end += 21
            (_x.azimuth, _x.image_width, _x.image_height, _x.frame_rate, _x.power, _x.calibrated,) = _get_struct_f3IfB().unpack(str[start:end])
            val3.calibrated = bool(val3.calibrated)
            _v20 = val3.state
            _x = _v20
            start = end
            end += 12
            (_x.id, _x.state, _x.status,) = _get_struct_3I().unpack(str[start:end])
            start = end
            end += 4
            (length,) = _struct_I.unpack(str[start:end])
            start = end
            end += length
            if python3:
              _v20.description = str[start:end].decode('utf-8', 'rosmsg')
            else:
              _v20.description = str[start:end]
            start = end
            end += 4
            (_v20.lastChange,) = _get_struct_I().unpack(str[start:end])
            start = end
            end += 4
            (length,) = _struct_I.unpack(str[start:end])
            _v20.metrics = []
            for i in range(0, length):
              val5 = digitaleye_msgs.msg.Metric()
              start = end
              end += 4
              (length,) = _struct_I.unpack(str[start:end])
              start = end
              end += length
              if python3:
                val5.name = str[start:end].decode('utf-8', 'rosmsg')
              else:
                val5.name = str[start:end]
              start = end
              end += 4
              (length,) = _struct_I.unpack(str[start:end])
              start = end
              end += length
              if python3:
                val5.value = str[start:end].decode('utf-8', 'rosmsg')
              else:
                val5.value = str[start:end]
              _v20.metrics.append(val5)
            _v21 = val3.imu
            start = end
            end += 4
            (_v21.heading,) = _get_struct_f().unpack(str[start:end])
            start = end
            end += 4
            (length,) = _struct_I.unpack(str[start:end])
            start = end
            end += length
            if python3:
              _v21.device_id = str[start:end].decode('utf-8', 'rosmsg')
            else:
              _v21.device_id = str[start:end]
            _v22 = _v21.imu
            _v23 = _v22.header
            start = end
            end += 4
            (_v23.seq,) = _get_struct_I().unpack(str[start:end])
            _v24 = _v23.stamp
            _x = _v24
            start = end
            end += 8
            (_x.secs, _x.nsecs,) = _get_struct_2I().unpack(str[start:end])
            start = end
            end += 4
            (length,) = _struct_I.unpack(str[start:end])
            start = end
            end += length
            if python3:
              _v23.frame_id = str[start:end].decode('utf-8', 'rosmsg')
            else:
              _v23.frame_id = str[start:end]
            _v25 = _v22.orientation
            _x = _v25
            start = end
            end += 32
            (_x.x, _x.y, _x.z, _x.w,) = _get_struct_4d().unpack(str[start:end])
            start = end
            end += 72
            _v22.orientation_covariance = _get_struct_9d().unpack(str[start:end])
            _v26 = _v22.angular_velocity
            _x = _v26
            start = end
            end += 24
            (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
            start = end
            end += 72
            _v22.angular_velocity_covariance = _get_struct_9d().unpack(str[start:end])
            _v27 = _v22.linear_acceleration
            _x = _v27
            start = end
            end += 24
            (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
            start = end
            end += 72
            _v22.linear_acceleration_covariance = _get_struct_9d().unpack(str[start:end])
            _v28 = _v21.magnetic_field
            _x = _v28
            start = end
            end += 24
            (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
            _x = _v21
            start = end
            end += 9
            (_x.roll, _x.pitch, _x.deviceCalibrated,) = _get_struct_2fB().unpack(str[start:end])
            _v21.deviceCalibrated = bool(_v21.deviceCalibrated)
            val2.sensors.append(val3)
          val1.components.append(val2)
        self.status.subsystems.append(val1)
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      _x = self
      buff.write(_get_struct_4I().pack(_x.status.started, _x.status.digitaleye.id, _x.status.digitaleye.state, _x.status.digitaleye.status))
      _x = self.status.digitaleye.description
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      _x = self.status.digitaleye.lastChange
      buff.write(_get_struct_I().pack(_x))
      length = len(self.status.digitaleye.metrics)
      buff.write(_struct_I.pack(length))
      for val1 in self.status.digitaleye.metrics:
        _x = val1.name
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        _x = val1.value
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
      length = len(self.status.subsystems)
      buff.write(_struct_I.pack(length))
      for val1 in self.status.subsystems:
        _v29 = val1.system
        _x = _v29
        buff.write(_get_struct_3I().pack(_x.id, _x.state, _x.status))
        _x = _v29.description
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        _x = _v29.lastChange
        buff.write(_get_struct_I().pack(_x))
        length = len(_v29.metrics)
        buff.write(_struct_I.pack(length))
        for val3 in _v29.metrics:
          _x = val3.name
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _x = val3.value
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        length = len(val1.components)
        buff.write(_struct_I.pack(length))
        for val2 in val1.components:
          _v30 = val2.component
          _x = _v30
          buff.write(_get_struct_3I().pack(_x.id, _x.state, _x.status))
          _x = _v30.description
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _x = _v30.lastChange
          buff.write(_get_struct_I().pack(_x))
          length = len(_v30.metrics)
          buff.write(_struct_I.pack(length))
          for val4 in _v30.metrics:
            _x = val4.name
            length = len(_x)
            if python3 or type(_x) == unicode:
              _x = _x.encode('utf-8')
              length = len(_x)
            buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
            _x = val4.value
            length = len(_x)
            if python3 or type(_x) == unicode:
              _x = _x.encode('utf-8')
              length = len(_x)
            buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          length = len(val2.sensors)
          buff.write(_struct_I.pack(length))
          for val3 in val2.sensors:
            _x = val3.sensor_id
            length = len(_x)
            if python3 or type(_x) == unicode:
              _x = _x.encode('utf-8')
              length = len(_x)
            buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
            _x = val3.model
            length = len(_x)
            if python3 or type(_x) == unicode:
              _x = _x.encode('utf-8')
              length = len(_x)
            buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
            _x = val3.type
            buff.write(_get_struct_I().pack(_x))
            _v31 = val3.pose
            _v32 = _v31.position
            _x = _v32
            buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
            _v33 = _v31.orientation
            _x = _v33
            buff.write(_get_struct_4d().pack(_x.x, _x.y, _x.z, _x.w))
            _x = val3
            buff.write(_get_struct_f3IfB().pack(_x.azimuth, _x.image_width, _x.image_height, _x.frame_rate, _x.power, _x.calibrated))
            _v34 = val3.state
            _x = _v34
            buff.write(_get_struct_3I().pack(_x.id, _x.state, _x.status))
            _x = _v34.description
            length = len(_x)
            if python3 or type(_x) == unicode:
              _x = _x.encode('utf-8')
              length = len(_x)
            buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
            _x = _v34.lastChange
            buff.write(_get_struct_I().pack(_x))
            length = len(_v34.metrics)
            buff.write(_struct_I.pack(length))
            for val5 in _v34.metrics:
              _x = val5.name
              length = len(_x)
              if python3 or type(_x) == unicode:
                _x = _x.encode('utf-8')
                length = len(_x)
              buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
              _x = val5.value
              length = len(_x)
              if python3 or type(_x) == unicode:
                _x = _x.encode('utf-8')
                length = len(_x)
              buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
            _v35 = val3.imu
            _x = _v35.heading
            buff.write(_get_struct_f().pack(_x))
            _x = _v35.device_id
            length = len(_x)
            if python3 or type(_x) == unicode:
              _x = _x.encode('utf-8')
              length = len(_x)
            buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
            _v36 = _v35.imu
            _v37 = _v36.header
            _x = _v37.seq
            buff.write(_get_struct_I().pack(_x))
            _v38 = _v37.stamp
            _x = _v38
            buff.write(_get_struct_2I().pack(_x.secs, _x.nsecs))
            _x = _v37.frame_id
            length = len(_x)
            if python3 or type(_x) == unicode:
              _x = _x.encode('utf-8')
              length = len(_x)
            buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
            _v39 = _v36.orientation
            _x = _v39
            buff.write(_get_struct_4d().pack(_x.x, _x.y, _x.z, _x.w))
            buff.write(_v36.orientation_covariance.tostring())
            _v40 = _v36.angular_velocity
            _x = _v40
            buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
            buff.write(_v36.angular_velocity_covariance.tostring())
            _v41 = _v36.linear_acceleration
            _x = _v41
            buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
            buff.write(_v36.linear_acceleration_covariance.tostring())
            _v42 = _v35.magnetic_field
            _x = _v42
            buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
            _x = _v35
            buff.write(_get_struct_2fB().pack(_x.roll, _x.pitch, _x.deviceCalibrated))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.status is None:
        self.status = digitaleye_msgs.msg.DigitalEyeStatus()
      end = 0
      _x = self
      start = end
      end += 16
      (_x.status.started, _x.status.digitaleye.id, _x.status.digitaleye.state, _x.status.digitaleye.status,) = _get_struct_4I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.status.digitaleye.description = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.status.digitaleye.description = str[start:end]
      start = end
      end += 4
      (self.status.digitaleye.lastChange,) = _get_struct_I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.status.digitaleye.metrics = []
      for i in range(0, length):
        val1 = digitaleye_msgs.msg.Metric()
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          val1.name = str[start:end].decode('utf-8', 'rosmsg')
        else:
          val1.name = str[start:end]
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          val1.value = str[start:end].decode('utf-8', 'rosmsg')
        else:
          val1.value = str[start:end]
        self.status.digitaleye.metrics.append(val1)
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.status.subsystems = []
      for i in range(0, length):
        val1 = digitaleye_msgs.msg.SystemState()
        _v43 = val1.system
        _x = _v43
        start = end
        end += 12
        (_x.id, _x.state, _x.status,) = _get_struct_3I().unpack(str[start:end])
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          _v43.description = str[start:end].decode('utf-8', 'rosmsg')
        else:
          _v43.description = str[start:end]
        start = end
        end += 4
        (_v43.lastChange,) = _get_struct_I().unpack(str[start:end])
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        _v43.metrics = []
        for i in range(0, length):
          val3 = digitaleye_msgs.msg.Metric()
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            val3.name = str[start:end].decode('utf-8', 'rosmsg')
          else:
            val3.name = str[start:end]
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            val3.value = str[start:end].decode('utf-8', 'rosmsg')
          else:
            val3.value = str[start:end]
          _v43.metrics.append(val3)
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        val1.components = []
        for i in range(0, length):
          val2 = digitaleye_msgs.msg.ComponentState()
          _v44 = val2.component
          _x = _v44
          start = end
          end += 12
          (_x.id, _x.state, _x.status,) = _get_struct_3I().unpack(str[start:end])
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            _v44.description = str[start:end].decode('utf-8', 'rosmsg')
          else:
            _v44.description = str[start:end]
          start = end
          end += 4
          (_v44.lastChange,) = _get_struct_I().unpack(str[start:end])
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          _v44.metrics = []
          for i in range(0, length):
            val4 = digitaleye_msgs.msg.Metric()
            start = end
            end += 4
            (length,) = _struct_I.unpack(str[start:end])
            start = end
            end += length
            if python3:
              val4.name = str[start:end].decode('utf-8', 'rosmsg')
            else:
              val4.name = str[start:end]
            start = end
            end += 4
            (length,) = _struct_I.unpack(str[start:end])
            start = end
            end += length
            if python3:
              val4.value = str[start:end].decode('utf-8', 'rosmsg')
            else:
              val4.value = str[start:end]
            _v44.metrics.append(val4)
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          val2.sensors = []
          for i in range(0, length):
            val3 = digitaleye_msgs.msg.Sensor()
            start = end
            end += 4
            (length,) = _struct_I.unpack(str[start:end])
            start = end
            end += length
            if python3:
              val3.sensor_id = str[start:end].decode('utf-8', 'rosmsg')
            else:
              val3.sensor_id = str[start:end]
            start = end
            end += 4
            (length,) = _struct_I.unpack(str[start:end])
            start = end
            end += length
            if python3:
              val3.model = str[start:end].decode('utf-8', 'rosmsg')
            else:
              val3.model = str[start:end]
            start = end
            end += 4
            (val3.type,) = _get_struct_I().unpack(str[start:end])
            _v45 = val3.pose
            _v46 = _v45.position
            _x = _v46
            start = end
            end += 24
            (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
            _v47 = _v45.orientation
            _x = _v47
            start = end
            end += 32
            (_x.x, _x.y, _x.z, _x.w,) = _get_struct_4d().unpack(str[start:end])
            _x = val3
            start = end
            end += 21
            (_x.azimuth, _x.image_width, _x.image_height, _x.frame_rate, _x.power, _x.calibrated,) = _get_struct_f3IfB().unpack(str[start:end])
            val3.calibrated = bool(val3.calibrated)
            _v48 = val3.state
            _x = _v48
            start = end
            end += 12
            (_x.id, _x.state, _x.status,) = _get_struct_3I().unpack(str[start:end])
            start = end
            end += 4
            (length,) = _struct_I.unpack(str[start:end])
            start = end
            end += length
            if python3:
              _v48.description = str[start:end].decode('utf-8', 'rosmsg')
            else:
              _v48.description = str[start:end]
            start = end
            end += 4
            (_v48.lastChange,) = _get_struct_I().unpack(str[start:end])
            start = end
            end += 4
            (length,) = _struct_I.unpack(str[start:end])
            _v48.metrics = []
            for i in range(0, length):
              val5 = digitaleye_msgs.msg.Metric()
              start = end
              end += 4
              (length,) = _struct_I.unpack(str[start:end])
              start = end
              end += length
              if python3:
                val5.name = str[start:end].decode('utf-8', 'rosmsg')
              else:
                val5.name = str[start:end]
              start = end
              end += 4
              (length,) = _struct_I.unpack(str[start:end])
              start = end
              end += length
              if python3:
                val5.value = str[start:end].decode('utf-8', 'rosmsg')
              else:
                val5.value = str[start:end]
              _v48.metrics.append(val5)
            _v49 = val3.imu
            start = end
            end += 4
            (_v49.heading,) = _get_struct_f().unpack(str[start:end])
            start = end
            end += 4
            (length,) = _struct_I.unpack(str[start:end])
            start = end
            end += length
            if python3:
              _v49.device_id = str[start:end].decode('utf-8', 'rosmsg')
            else:
              _v49.device_id = str[start:end]
            _v50 = _v49.imu
            _v51 = _v50.header
            start = end
            end += 4
            (_v51.seq,) = _get_struct_I().unpack(str[start:end])
            _v52 = _v51.stamp
            _x = _v52
            start = end
            end += 8
            (_x.secs, _x.nsecs,) = _get_struct_2I().unpack(str[start:end])
            start = end
            end += 4
            (length,) = _struct_I.unpack(str[start:end])
            start = end
            end += length
            if python3:
              _v51.frame_id = str[start:end].decode('utf-8', 'rosmsg')
            else:
              _v51.frame_id = str[start:end]
            _v53 = _v50.orientation
            _x = _v53
            start = end
            end += 32
            (_x.x, _x.y, _x.z, _x.w,) = _get_struct_4d().unpack(str[start:end])
            start = end
            end += 72
            _v50.orientation_covariance = numpy.frombuffer(str[start:end], dtype=numpy.float64, count=9)
            _v54 = _v50.angular_velocity
            _x = _v54
            start = end
            end += 24
            (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
            start = end
            end += 72
            _v50.angular_velocity_covariance = numpy.frombuffer(str[start:end], dtype=numpy.float64, count=9)
            _v55 = _v50.linear_acceleration
            _x = _v55
            start = end
            end += 24
            (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
            start = end
            end += 72
            _v50.linear_acceleration_covariance = numpy.frombuffer(str[start:end], dtype=numpy.float64, count=9)
            _v56 = _v49.magnetic_field
            _x = _v56
            start = end
            end += 24
            (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
            _x = _v49
            start = end
            end += 9
            (_x.roll, _x.pitch, _x.deviceCalibrated,) = _get_struct_2fB().unpack(str[start:end])
            _v49.deviceCalibrated = bool(_v49.deviceCalibrated)
            val2.sensors.append(val3)
          val1.components.append(val2)
        self.status.subsystems.append(val1)
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
_struct_2I = None
def _get_struct_2I():
    global _struct_2I
    if _struct_2I is None:
        _struct_2I = struct.Struct("<2I")
    return _struct_2I
_struct_2fB = None
def _get_struct_2fB():
    global _struct_2fB
    if _struct_2fB is None:
        _struct_2fB = struct.Struct("<2fB")
    return _struct_2fB
_struct_3I = None
def _get_struct_3I():
    global _struct_3I
    if _struct_3I is None:
        _struct_3I = struct.Struct("<3I")
    return _struct_3I
_struct_3d = None
def _get_struct_3d():
    global _struct_3d
    if _struct_3d is None:
        _struct_3d = struct.Struct("<3d")
    return _struct_3d
_struct_4I = None
def _get_struct_4I():
    global _struct_4I
    if _struct_4I is None:
        _struct_4I = struct.Struct("<4I")
    return _struct_4I
_struct_4d = None
def _get_struct_4d():
    global _struct_4d
    if _struct_4d is None:
        _struct_4d = struct.Struct("<4d")
    return _struct_4d
_struct_9d = None
def _get_struct_9d():
    global _struct_9d
    if _struct_9d is None:
        _struct_9d = struct.Struct("<9d")
    return _struct_9d
_struct_f = None
def _get_struct_f():
    global _struct_f
    if _struct_f is None:
        _struct_f = struct.Struct("<f")
    return _struct_f
_struct_f3IfB = None
def _get_struct_f3IfB():
    global _struct_f3IfB
    if _struct_f3IfB is None:
        _struct_f3IfB = struct.Struct("<f3IfB")
    return _struct_f3IfB
class GetStatus(object):
  _type          = 'digitaleye_msgs/GetStatus'
  _md5sum = '3debe849e7d84e1c8a45738e73fc747e'
  _request_class  = GetStatusRequest
  _response_class = GetStatusResponse



# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/GetEntrypointRequest.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct


class GetEntrypointRequest(genpy.Message):
  _md5sum = "10feff0d020ceb3c871bb97db52e5033"
  _type = "digitaleye_msgs/GetEntrypointRequest"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """# Returns all entry points associated to a given UAV

# agent registration of the UAV
uint64 agent_reg

"""
  __slots__ = ['agent_reg']
  _slot_types = ['uint64']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       agent_reg

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(GetEntrypointRequest, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.agent_reg is None:
        self.agent_reg = 0
    else:
      self.agent_reg = 0

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      _x = self.agent_reg
      buff.write(_get_struct_Q().pack(_x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      end = 0
      start = end
      end += 8
      (self.agent_reg,) = _get_struct_Q().unpack(str[start:end])
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      _x = self.agent_reg
      buff.write(_get_struct_Q().pack(_x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      end = 0
      start = end
      end += 8
      (self.agent_reg,) = _get_struct_Q().unpack(str[start:end])
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
_struct_Q = None
def _get_struct_Q():
    global _struct_Q
    if _struct_Q is None:
        _struct_Q = struct.Struct("<Q")
    return _struct_Q
# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/GetEntrypointResponse.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct

import digitaleye_msgs.msg
import geometry_msgs.msg
import std_msgs.msg

class GetEntrypointResponse(genpy.Message):
  _md5sum = "7394b4d618990e3129e380d7a4cc8e04"
  _type = "digitaleye_msgs/GetEntrypointResponse"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """
# list of entry point(s)
digitaleye_msgs/UavFlightData[] flight_data


================================================================================
MSG: digitaleye_msgs/UavFlightData
# Specific flight data for a given UAV

# standard header
std_msgs/Header header

# agent registration of the UAV
uint64 agent_reg

# list of point(s) linked to msg_type
digitaleye_msgs/Flightpath flight_path

# type of flight data
uint32 msg_type


# msg_type constants

# Take off data (hover point)
uint32 TAKE_OFF=9400
# Landing data (landing point)
uint32 LANDING=9401
# Reset (no flight data associated) 
uint32 RESET=9402
# flight exiting the MGS
uint32 FLIGHT_OUT=9403
# flight entering the MGS
uint32 FLIGHT_IN=9404
# entry point data: TOLZ id
uint32 TOLZ_ENTRY=9405
# entry point data: local coordinates (meters)
uint32 COORD_ENTRY=9406

================================================================================
MSG: std_msgs/Header
# Standard metadata for higher-level stamped data types.
# This is generally used to communicate timestamped data 
# in a particular coordinate frame.
# 
# sequence ID: consecutively increasing ID 
uint32 seq
#Two-integer timestamp that is expressed as:
# * stamp.sec: seconds (stamp_secs) since epoch (in Python the variable is called 'secs')
# * stamp.nsec: nanoseconds since stamp_secs (in Python the variable is called 'nsecs')
# time-handling sugar is provided by the client library
time stamp
#Frame this data is associated with
string frame_id

================================================================================
MSG: digitaleye_msgs/Flightpath
# Fligh path definition

# TOLZ id (0 = N/A)
uint32 tolz_id

# list of flight point(s)
digitaleye_msgs/Flightpoint[] flight_points

================================================================================
MSG: digitaleye_msgs/Flightpoint
# Flight point definition

# local coordinates of point (meters)
geometry_msgs/Point coord

# desired speed to reach this point (m/s)
float32 speed

================================================================================
MSG: geometry_msgs/Point
# This contains the position of a point in free space
float64 x
float64 y
float64 z
"""
  __slots__ = ['flight_data']
  _slot_types = ['digitaleye_msgs/UavFlightData[]']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       flight_data

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(GetEntrypointResponse, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.flight_data is None:
        self.flight_data = []
    else:
      self.flight_data = []

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      length = len(self.flight_data)
      buff.write(_struct_I.pack(length))
      for val1 in self.flight_data:
        _v1 = val1.header
        _x = _v1.seq
        buff.write(_get_struct_I().pack(_x))
        _v2 = _v1.stamp
        _x = _v2
        buff.write(_get_struct_2I().pack(_x.secs, _x.nsecs))
        _x = _v1.frame_id
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        _x = val1.agent_reg
        buff.write(_get_struct_Q().pack(_x))
        _v3 = val1.flight_path
        _x = _v3.tolz_id
        buff.write(_get_struct_I().pack(_x))
        length = len(_v3.flight_points)
        buff.write(_struct_I.pack(length))
        for val3 in _v3.flight_points:
          _v4 = val3.coord
          _x = _v4
          buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
          _x = val3.speed
          buff.write(_get_struct_f().pack(_x))
        _x = val1.msg_type
        buff.write(_get_struct_I().pack(_x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.flight_data is None:
        self.flight_data = None
      end = 0
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.flight_data = []
      for i in range(0, length):
        val1 = digitaleye_msgs.msg.UavFlightData()
        _v5 = val1.header
        start = end
        end += 4
        (_v5.seq,) = _get_struct_I().unpack(str[start:end])
        _v6 = _v5.stamp
        _x = _v6
        start = end
        end += 8
        (_x.secs, _x.nsecs,) = _get_struct_2I().unpack(str[start:end])
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          _v5.frame_id = str[start:end].decode('utf-8', 'rosmsg')
        else:
          _v5.frame_id = str[start:end]
        start = end
        end += 8
        (val1.agent_reg,) = _get_struct_Q().unpack(str[start:end])
        _v7 = val1.flight_path
        start = end
        end += 4
        (_v7.tolz_id,) = _get_struct_I().unpack(str[start:end])
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        _v7.flight_points = []
        for i in range(0, length):
          val3 = digitaleye_msgs.msg.Flightpoint()
          _v8 = val3.coord
          _x = _v8
          start = end
          end += 24
          (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
          start = end
          end += 4
          (val3.speed,) = _get_struct_f().unpack(str[start:end])
          _v7.flight_points.append(val3)
        start = end
        end += 4
        (val1.msg_type,) = _get_struct_I().unpack(str[start:end])
        self.flight_data.append(val1)
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      length = len(self.flight_data)
      buff.write(_struct_I.pack(length))
      for val1 in self.flight_data:
        _v9 = val1.header
        _x = _v9.seq
        buff.write(_get_struct_I().pack(_x))
        _v10 = _v9.stamp
        _x = _v10
        buff.write(_get_struct_2I().pack(_x.secs, _x.nsecs))
        _x = _v9.frame_id
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        _x = val1.agent_reg
        buff.write(_get_struct_Q().pack(_x))
        _v11 = val1.flight_path
        _x = _v11.tolz_id
        buff.write(_get_struct_I().pack(_x))
        length = len(_v11.flight_points)
        buff.write(_struct_I.pack(length))
        for val3 in _v11.flight_points:
          _v12 = val3.coord
          _x = _v12
          buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
          _x = val3.speed
          buff.write(_get_struct_f().pack(_x))
        _x = val1.msg_type
        buff.write(_get_struct_I().pack(_x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.flight_data is None:
        self.flight_data = None
      end = 0
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.flight_data = []
      for i in range(0, length):
        val1 = digitaleye_msgs.msg.UavFlightData()
        _v13 = val1.header
        start = end
        end += 4
        (_v13.seq,) = _get_struct_I().unpack(str[start:end])
        _v14 = _v13.stamp
        _x = _v14
        start = end
        end += 8
        (_x.secs, _x.nsecs,) = _get_struct_2I().unpack(str[start:end])
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          _v13.frame_id = str[start:end].decode('utf-8', 'rosmsg')
        else:
          _v13.frame_id = str[start:end]
        start = end
        end += 8
        (val1.agent_reg,) = _get_struct_Q().unpack(str[start:end])
        _v15 = val1.flight_path
        start = end
        end += 4
        (_v15.tolz_id,) = _get_struct_I().unpack(str[start:end])
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        _v15.flight_points = []
        for i in range(0, length):
          val3 = digitaleye_msgs.msg.Flightpoint()
          _v16 = val3.coord
          _x = _v16
          start = end
          end += 24
          (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
          start = end
          end += 4
          (val3.speed,) = _get_struct_f().unpack(str[start:end])
          _v15.flight_points.append(val3)
        start = end
        end += 4
        (val1.msg_type,) = _get_struct_I().unpack(str[start:end])
        self.flight_data.append(val1)
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
_struct_2I = None
def _get_struct_2I():
    global _struct_2I
    if _struct_2I is None:
        _struct_2I = struct.Struct("<2I")
    return _struct_2I
_struct_3d = None
def _get_struct_3d():
    global _struct_3d
    if _struct_3d is None:
        _struct_3d = struct.Struct("<3d")
    return _struct_3d
_struct_Q = None
def _get_struct_Q():
    global _struct_Q
    if _struct_Q is None:
        _struct_Q = struct.Struct("<Q")
    return _struct_Q
_struct_f = None
def _get_struct_f():
    global _struct_f
    if _struct_f is None:
        _struct_f = struct.Struct("<f")
    return _struct_f
class GetEntrypoint(object):
  _type          = 'digitaleye_msgs/GetEntrypoint'
  _md5sum = '5aecbcf7a3f05b23a7227ea0206f3cfe'
  _request_class  = GetEntrypointRequest
  _response_class = GetEntrypointResponse



# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/Zone.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct

import geometry_msgs.msg

class Zone(genpy.Message):
  _md5sum = "6a4f77b9c8158efa41bb89b6588f7ae6"
  _type = "digitaleye_msgs/Zone"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """# Boundaries of an area managed by the DigitalEye

# Unique identifier of the zone being defined
uint32 zone_id

# list of local coordinates describing the boundaries 
# of the defined zone (meters)
geometry_msgs/Polygon path

# height to which the managed zone extends (meters)
float32 height

================================================================================
MSG: geometry_msgs/Polygon
#A specification of a polygon where the first and last points are assumed to be connected
Point32[] points

================================================================================
MSG: geometry_msgs/Point32
# This contains the position of a point in free space(with 32 bits of precision).
# It is recommeded to use Point wherever possible instead of Point32.  
# 
# This recommendation is to promote interoperability.  
#
# This message is designed to take up less space when sending
# lots of points at once, as in the case of a PointCloud.  

float32 x
float32 y
float32 z"""
  __slots__ = ['zone_id','path','height']
  _slot_types = ['uint32','geometry_msgs/Polygon','float32']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       zone_id,path,height

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(Zone, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.zone_id is None:
        self.zone_id = 0
      if self.path is None:
        self.path = geometry_msgs.msg.Polygon()
      if self.height is None:
        self.height = 0.
    else:
      self.zone_id = 0
      self.path = geometry_msgs.msg.Polygon()
      self.height = 0.

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      _x = self.zone_id
      buff.write(_get_struct_I().pack(_x))
      length = len(self.path.points)
      buff.write(_struct_I.pack(length))
      for val1 in self.path.points:
        _x = val1
        buff.write(_get_struct_3f().pack(_x.x, _x.y, _x.z))
      _x = self.height
      buff.write(_get_struct_f().pack(_x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.path is None:
        self.path = geometry_msgs.msg.Polygon()
      end = 0
      start = end
      end += 4
      (self.zone_id,) = _get_struct_I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.path.points = []
      for i in range(0, length):
        val1 = geometry_msgs.msg.Point32()
        _x = val1
        start = end
        end += 12
        (_x.x, _x.y, _x.z,) = _get_struct_3f().unpack(str[start:end])
        self.path.points.append(val1)
      start = end
      end += 4
      (self.height,) = _get_struct_f().unpack(str[start:end])
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      _x = self.zone_id
      buff.write(_get_struct_I().pack(_x))
      length = len(self.path.points)
      buff.write(_struct_I.pack(length))
      for val1 in self.path.points:
        _x = val1
        buff.write(_get_struct_3f().pack(_x.x, _x.y, _x.z))
      _x = self.height
      buff.write(_get_struct_f().pack(_x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.path is None:
        self.path = geometry_msgs.msg.Polygon()
      end = 0
      start = end
      end += 4
      (self.zone_id,) = _get_struct_I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.path.points = []
      for i in range(0, length):
        val1 = geometry_msgs.msg.Point32()
        _x = val1
        start = end
        end += 12
        (_x.x, _x.y, _x.z,) = _get_struct_3f().unpack(str[start:end])
        self.path.points.append(val1)
      start = end
      end += 4
      (self.height,) = _get_struct_f().unpack(str[start:end])
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
_struct_3f = None
def _get_struct_3f():
    global _struct_3f
    if _struct_3f is None:
        _struct_3f = struct.Struct("<3f")
    return _struct_3f
_struct_f = None
def _get_struct_f():
    global _struct_f
    if _struct_f is None:
        _struct_f = struct.Struct("<f")
    return _struct_f



# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/GetUavIdStringRequest.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct


class GetUavIdStringRequest(genpy.Message):
  _md5sum = "3068481c57aad1c875ba669a781146fc"
  _type = "digitaleye_msgs/GetUavIdStringRequest"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """# Returns the public agent registration of the UAV matching the given unique internal id
# If there is no existing match, the service returns false

# unique internal UAV id
uint64 agent_reg_uint
"""
  __slots__ = ['agent_reg_uint']
  _slot_types = ['uint64']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       agent_reg_uint

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(GetUavIdStringRequest, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.agent_reg_uint is None:
        self.agent_reg_uint = 0
    else:
      self.agent_reg_uint = 0

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      _x = self.agent_reg_uint
      buff.write(_get_struct_Q().pack(_x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      end = 0
      start = end
      end += 8
      (self.agent_reg_uint,) = _get_struct_Q().unpack(str[start:end])
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      _x = self.agent_reg_uint
      buff.write(_get_struct_Q().pack(_x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      end = 0
      start = end
      end += 8
      (self.agent_reg_uint,) = _get_struct_Q().unpack(str[start:end])
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
_struct_Q = None
def _get_struct_Q():
    global _struct_Q
    if _struct_Q is None:
        _struct_Q = struct.Struct("<Q")
    return _struct_Q
# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/GetUavIdStringResponse.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct


class GetUavIdStringResponse(genpy.Message):
  _md5sum = "96978dbb9a753d06501b4fa6e1498f49"
  _type = "digitaleye_msgs/GetUavIdStringResponse"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """
# UAV public agent registration if existing
string agent_reg_str

"""
  __slots__ = ['agent_reg_str']
  _slot_types = ['string']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       agent_reg_str

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(GetUavIdStringResponse, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.agent_reg_str is None:
        self.agent_reg_str = ''
    else:
      self.agent_reg_str = ''

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      _x = self.agent_reg_str
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      end = 0
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.agent_reg_str = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.agent_reg_str = str[start:end]
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      _x = self.agent_reg_str
      length = len(_x)
      if python3 or type(_x) == unicode:
        _x = _x.encode('utf-8')
        length = len(_x)
      buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      end = 0
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      start = end
      end += length
      if python3:
        self.agent_reg_str = str[start:end].decode('utf-8', 'rosmsg')
      else:
        self.agent_reg_str = str[start:end]
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
class GetUavIdString(object):
  _type          = 'digitaleye_msgs/GetUavIdString'
  _md5sum = '814553d83afbc2486ac11dd1e37e17b8'
  _request_class  = GetUavIdStringRequest
  _response_class = GetUavIdStringResponse



# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/Flightpath.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct

import digitaleye_msgs.msg
import geometry_msgs.msg

class Flightpath(genpy.Message):
  _md5sum = "f2bf5f4e25462628c7f7a1331c74ab54"
  _type = "digitaleye_msgs/Flightpath"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """# Fligh path definition

# TOLZ id (0 = N/A)
uint32 tolz_id

# list of flight point(s)
digitaleye_msgs/Flightpoint[] flight_points

================================================================================
MSG: digitaleye_msgs/Flightpoint
# Flight point definition

# local coordinates of point (meters)
geometry_msgs/Point coord

# desired speed to reach this point (m/s)
float32 speed

================================================================================
MSG: geometry_msgs/Point
# This contains the position of a point in free space
float64 x
float64 y
float64 z
"""
  __slots__ = ['tolz_id','flight_points']
  _slot_types = ['uint32','digitaleye_msgs/Flightpoint[]']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       tolz_id,flight_points

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(Flightpath, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.tolz_id is None:
        self.tolz_id = 0
      if self.flight_points is None:
        self.flight_points = []
    else:
      self.tolz_id = 0
      self.flight_points = []

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      _x = self.tolz_id
      buff.write(_get_struct_I().pack(_x))
      length = len(self.flight_points)
      buff.write(_struct_I.pack(length))
      for val1 in self.flight_points:
        _v1 = val1.coord
        _x = _v1
        buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
        _x = val1.speed
        buff.write(_get_struct_f().pack(_x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.flight_points is None:
        self.flight_points = None
      end = 0
      start = end
      end += 4
      (self.tolz_id,) = _get_struct_I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.flight_points = []
      for i in range(0, length):
        val1 = digitaleye_msgs.msg.Flightpoint()
        _v2 = val1.coord
        _x = _v2
        start = end
        end += 24
        (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
        start = end
        end += 4
        (val1.speed,) = _get_struct_f().unpack(str[start:end])
        self.flight_points.append(val1)
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      _x = self.tolz_id
      buff.write(_get_struct_I().pack(_x))
      length = len(self.flight_points)
      buff.write(_struct_I.pack(length))
      for val1 in self.flight_points:
        _v3 = val1.coord
        _x = _v3
        buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
        _x = val1.speed
        buff.write(_get_struct_f().pack(_x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.flight_points is None:
        self.flight_points = None
      end = 0
      start = end
      end += 4
      (self.tolz_id,) = _get_struct_I().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.flight_points = []
      for i in range(0, length):
        val1 = digitaleye_msgs.msg.Flightpoint()
        _v4 = val1.coord
        _x = _v4
        start = end
        end += 24
        (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
        start = end
        end += 4
        (val1.speed,) = _get_struct_f().unpack(str[start:end])
        self.flight_points.append(val1)
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
_struct_3d = None
def _get_struct_3d():
    global _struct_3d
    if _struct_3d is None:
        _struct_3d = struct.Struct("<3d")
    return _struct_3d
_struct_f = None
def _get_struct_f():
    global _struct_f
    if _struct_f is None:
        _struct_f = struct.Struct("<f")
    return _struct_f



# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/Position.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct

import digitaleye_msgs.msg
import geometry_msgs.msg
import sensor_msgs.msg
import std_msgs.msg

class Position(genpy.Message):
  _md5sum = "d47ae8ad3a580532f063923517626419"
  _type = "digitaleye_msgs/Position"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """# Position of all of the DigitalEye’s physical components

# list of pole(s) in the current DigitalEye
# configuration and their positions
digitaleye_msgs/Pole[] poles

================================================================================
MSG: digitaleye_msgs/Pole
# Description of the position and status of
# a DigitalEye’s sensor pole

# unique identifier of the pole being described
uint32 id

# pole’s IP address on the main subnet
string ip_address

# IP address of the MVC attached to the pole
string mvc

# MAC address of the iot locator attached to the pole
string iot

# unique identifier of the reference frame in which
# the pole’s position is given
uint32 position_frame

# coordinates of the pole within the specified
# reference frame (either in meters or in order lat, long in degrees
# and alt in meters (WGS84 ellipsoid or MSL)
geometry_msgs/Point position

# unique identifier of the reference frame in which
# the pole’s orientation is given
uint32 orientation_frame

# direction the pole is facing within the specified
# reference frame
float32 orientation

# distance of the pole’s RTK receiver above the ground (meters)
float32 height

# current state of the pole
digitaleye_msgs/ComponentState state

# Key/value pairs representing the currently active pole settings
digitaleye_msgs/Metric[] settings

================================================================================
MSG: geometry_msgs/Point
# This contains the position of a point in free space
float64 x
float64 y
float64 z

================================================================================
MSG: digitaleye_msgs/ComponentState
# State of a system component and its attached sensor(s)

# state of the component
digitaleye_msgs/State component

# state(s) of the component’s attached sensor(s)
digitaleye_msgs/Sensor[] sensors

================================================================================
MSG: digitaleye_msgs/State
# Details of a system’s status

# unique identifier of the system
# whose status is being reported
uint32 id

# system’s current state within the 
# DigitalEye state machine
uint32 state

# system’s substatus within the current state,
# unique to each system
uint32 status

# description of the system’s current state/status
string description

# timestamp indicating last change in state or status
# (epoch time in sec)
uint32 lastChange

# list of performance metrics associated with the
# current state
digitaleye_msgs/Metric[] metrics

================================================================================
MSG: digitaleye_msgs/Metric
# Performance indicator for a subsystem,
# component or sensor

# name of the performance indicator
string name

# value of the performance indicator
string value

================================================================================
MSG: digitaleye_msgs/Sensor
# Description of a monitoring DigitalEye sensor
# and its properties

# unique identifier of the sensor
# e.g. hardware serial number
string sensor_id

# brand/model of sensor hardware
string model

# type of sensor being described
# e.g. camera, LIDAR, etc.
uint32 type

# position of the sensor in
# the DigitalEye’s local reference frame (meters)
geometry_msgs/Pose pose

# direction in which the sensor is facing
# with respect to the local frame’s x-axis
float32 azimuth

# resolution height of the image captured by the sensor
uint32 image_width

# resolution width of the image captured by the sensor
uint32 image_height

# frame rate of a vision sensor
uint32 frame_rate

# sensor’s current power level
float32 power

# Whether or not the sensor has been calibrated
bool calibrated

# current state of the sensor
digitaleye_msgs/State state

# Sensor inertial measurements
digitaleye_msgs/IMUValue imu

================================================================================
MSG: geometry_msgs/Pose
# A representation of pose in free space, composed of position and orientation. 
Point position
Quaternion orientation

================================================================================
MSG: geometry_msgs/Quaternion
# This represents an orientation in free space in quaternion form.

float64 x
float64 y
float64 z
float64 w

================================================================================
MSG: digitaleye_msgs/IMUValue
# Description of an IMU value reading

# Imu heading
float32 heading

# Unique identifier of the sensor
# e.g. hardware serial number
string device_id

# Imu measurements
sensor_msgs/Imu imu

# Magenetometer readings
geometry_msgs/Vector3 magnetic_field

# Imu reading of roll
float32 roll

# Imu reading of pitch
float32 pitch

# Calibration status
bool deviceCalibrated

================================================================================
MSG: sensor_msgs/Imu
# This is a message to hold data from an IMU (Inertial Measurement Unit)
#
# Accelerations should be in m/s^2 (not in g's), and rotational velocity should be in rad/sec
#
# If the covariance of the measurement is known, it should be filled in (if all you know is the 
# variance of each measurement, e.g. from the datasheet, just put those along the diagonal)
# A covariance matrix of all zeros will be interpreted as "covariance unknown", and to use the
# data a covariance will have to be assumed or gotten from some other source
#
# If you have no estimate for one of the data elements (e.g. your IMU doesn't produce an orientation 
# estimate), please set element 0 of the associated covariance matrix to -1
# If you are interpreting this message, please check for a value of -1 in the first element of each 
# covariance matrix, and disregard the associated estimate.

Header header

geometry_msgs/Quaternion orientation
float64[9] orientation_covariance # Row major about x, y, z axes

geometry_msgs/Vector3 angular_velocity
float64[9] angular_velocity_covariance # Row major about x, y, z axes

geometry_msgs/Vector3 linear_acceleration
float64[9] linear_acceleration_covariance # Row major x, y z 

================================================================================
MSG: std_msgs/Header
# Standard metadata for higher-level stamped data types.
# This is generally used to communicate timestamped data 
# in a particular coordinate frame.
# 
# sequence ID: consecutively increasing ID 
uint32 seq
#Two-integer timestamp that is expressed as:
# * stamp.sec: seconds (stamp_secs) since epoch (in Python the variable is called 'secs')
# * stamp.nsec: nanoseconds since stamp_secs (in Python the variable is called 'nsecs')
# time-handling sugar is provided by the client library
time stamp
#Frame this data is associated with
string frame_id

================================================================================
MSG: geometry_msgs/Vector3
# This represents a vector in free space. 
# It is only meant to represent a direction. Therefore, it does not
# make sense to apply a translation to it (e.g., when applying a 
# generic rigid transformation to a Vector3, tf2 will only apply the
# rotation). If you want your data to be translatable too, use the
# geometry_msgs/Point message instead.

float64 x
float64 y
float64 z"""
  __slots__ = ['poles']
  _slot_types = ['digitaleye_msgs/Pole[]']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       poles

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(Position, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.poles is None:
        self.poles = []
    else:
      self.poles = []

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      length = len(self.poles)
      buff.write(_struct_I.pack(length))
      for val1 in self.poles:
        _x = val1.id
        buff.write(_get_struct_I().pack(_x))
        _x = val1.ip_address
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        _x = val1.mvc
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        _x = val1.iot
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        _x = val1.position_frame
        buff.write(_get_struct_I().pack(_x))
        _v1 = val1.position
        _x = _v1
        buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
        _x = val1
        buff.write(_get_struct_I2f().pack(_x.orientation_frame, _x.orientation, _x.height))
        _v2 = val1.state
        _v3 = _v2.component
        _x = _v3
        buff.write(_get_struct_3I().pack(_x.id, _x.state, _x.status))
        _x = _v3.description
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        _x = _v3.lastChange
        buff.write(_get_struct_I().pack(_x))
        length = len(_v3.metrics)
        buff.write(_struct_I.pack(length))
        for val4 in _v3.metrics:
          _x = val4.name
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _x = val4.value
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        length = len(_v2.sensors)
        buff.write(_struct_I.pack(length))
        for val3 in _v2.sensors:
          _x = val3.sensor_id
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _x = val3.model
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _x = val3.type
          buff.write(_get_struct_I().pack(_x))
          _v4 = val3.pose
          _v5 = _v4.position
          _x = _v5
          buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
          _v6 = _v4.orientation
          _x = _v6
          buff.write(_get_struct_4d().pack(_x.x, _x.y, _x.z, _x.w))
          _x = val3
          buff.write(_get_struct_f3IfB().pack(_x.azimuth, _x.image_width, _x.image_height, _x.frame_rate, _x.power, _x.calibrated))
          _v7 = val3.state
          _x = _v7
          buff.write(_get_struct_3I().pack(_x.id, _x.state, _x.status))
          _x = _v7.description
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _x = _v7.lastChange
          buff.write(_get_struct_I().pack(_x))
          length = len(_v7.metrics)
          buff.write(_struct_I.pack(length))
          for val5 in _v7.metrics:
            _x = val5.name
            length = len(_x)
            if python3 or type(_x) == unicode:
              _x = _x.encode('utf-8')
              length = len(_x)
            buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
            _x = val5.value
            length = len(_x)
            if python3 or type(_x) == unicode:
              _x = _x.encode('utf-8')
              length = len(_x)
            buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _v8 = val3.imu
          _x = _v8.heading
          buff.write(_get_struct_f().pack(_x))
          _x = _v8.device_id
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _v9 = _v8.imu
          _v10 = _v9.header
          _x = _v10.seq
          buff.write(_get_struct_I().pack(_x))
          _v11 = _v10.stamp
          _x = _v11
          buff.write(_get_struct_2I().pack(_x.secs, _x.nsecs))
          _x = _v10.frame_id
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _v12 = _v9.orientation
          _x = _v12
          buff.write(_get_struct_4d().pack(_x.x, _x.y, _x.z, _x.w))
          buff.write(_get_struct_9d().pack(*_v9.orientation_covariance))
          _v13 = _v9.angular_velocity
          _x = _v13
          buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
          buff.write(_get_struct_9d().pack(*_v9.angular_velocity_covariance))
          _v14 = _v9.linear_acceleration
          _x = _v14
          buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
          buff.write(_get_struct_9d().pack(*_v9.linear_acceleration_covariance))
          _v15 = _v8.magnetic_field
          _x = _v15
          buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
          _x = _v8
          buff.write(_get_struct_2fB().pack(_x.roll, _x.pitch, _x.deviceCalibrated))
        length = len(val1.settings)
        buff.write(_struct_I.pack(length))
        for val2 in val1.settings:
          _x = val2.name
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _x = val2.value
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.poles is None:
        self.poles = None
      end = 0
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.poles = []
      for i in range(0, length):
        val1 = digitaleye_msgs.msg.Pole()
        start = end
        end += 4
        (val1.id,) = _get_struct_I().unpack(str[start:end])
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          val1.ip_address = str[start:end].decode('utf-8', 'rosmsg')
        else:
          val1.ip_address = str[start:end]
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          val1.mvc = str[start:end].decode('utf-8', 'rosmsg')
        else:
          val1.mvc = str[start:end]
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          val1.iot = str[start:end].decode('utf-8', 'rosmsg')
        else:
          val1.iot = str[start:end]
        start = end
        end += 4
        (val1.position_frame,) = _get_struct_I().unpack(str[start:end])
        _v16 = val1.position
        _x = _v16
        start = end
        end += 24
        (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
        _x = val1
        start = end
        end += 12
        (_x.orientation_frame, _x.orientation, _x.height,) = _get_struct_I2f().unpack(str[start:end])
        _v17 = val1.state
        _v18 = _v17.component
        _x = _v18
        start = end
        end += 12
        (_x.id, _x.state, _x.status,) = _get_struct_3I().unpack(str[start:end])
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          _v18.description = str[start:end].decode('utf-8', 'rosmsg')
        else:
          _v18.description = str[start:end]
        start = end
        end += 4
        (_v18.lastChange,) = _get_struct_I().unpack(str[start:end])
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        _v18.metrics = []
        for i in range(0, length):
          val4 = digitaleye_msgs.msg.Metric()
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            val4.name = str[start:end].decode('utf-8', 'rosmsg')
          else:
            val4.name = str[start:end]
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            val4.value = str[start:end].decode('utf-8', 'rosmsg')
          else:
            val4.value = str[start:end]
          _v18.metrics.append(val4)
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        _v17.sensors = []
        for i in range(0, length):
          val3 = digitaleye_msgs.msg.Sensor()
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            val3.sensor_id = str[start:end].decode('utf-8', 'rosmsg')
          else:
            val3.sensor_id = str[start:end]
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            val3.model = str[start:end].decode('utf-8', 'rosmsg')
          else:
            val3.model = str[start:end]
          start = end
          end += 4
          (val3.type,) = _get_struct_I().unpack(str[start:end])
          _v19 = val3.pose
          _v20 = _v19.position
          _x = _v20
          start = end
          end += 24
          (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
          _v21 = _v19.orientation
          _x = _v21
          start = end
          end += 32
          (_x.x, _x.y, _x.z, _x.w,) = _get_struct_4d().unpack(str[start:end])
          _x = val3
          start = end
          end += 21
          (_x.azimuth, _x.image_width, _x.image_height, _x.frame_rate, _x.power, _x.calibrated,) = _get_struct_f3IfB().unpack(str[start:end])
          val3.calibrated = bool(val3.calibrated)
          _v22 = val3.state
          _x = _v22
          start = end
          end += 12
          (_x.id, _x.state, _x.status,) = _get_struct_3I().unpack(str[start:end])
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            _v22.description = str[start:end].decode('utf-8', 'rosmsg')
          else:
            _v22.description = str[start:end]
          start = end
          end += 4
          (_v22.lastChange,) = _get_struct_I().unpack(str[start:end])
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          _v22.metrics = []
          for i in range(0, length):
            val5 = digitaleye_msgs.msg.Metric()
            start = end
            end += 4
            (length,) = _struct_I.unpack(str[start:end])
            start = end
            end += length
            if python3:
              val5.name = str[start:end].decode('utf-8', 'rosmsg')
            else:
              val5.name = str[start:end]
            start = end
            end += 4
            (length,) = _struct_I.unpack(str[start:end])
            start = end
            end += length
            if python3:
              val5.value = str[start:end].decode('utf-8', 'rosmsg')
            else:
              val5.value = str[start:end]
            _v22.metrics.append(val5)
          _v23 = val3.imu
          start = end
          end += 4
          (_v23.heading,) = _get_struct_f().unpack(str[start:end])
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            _v23.device_id = str[start:end].decode('utf-8', 'rosmsg')
          else:
            _v23.device_id = str[start:end]
          _v24 = _v23.imu
          _v25 = _v24.header
          start = end
          end += 4
          (_v25.seq,) = _get_struct_I().unpack(str[start:end])
          _v26 = _v25.stamp
          _x = _v26
          start = end
          end += 8
          (_x.secs, _x.nsecs,) = _get_struct_2I().unpack(str[start:end])
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            _v25.frame_id = str[start:end].decode('utf-8', 'rosmsg')
          else:
            _v25.frame_id = str[start:end]
          _v27 = _v24.orientation
          _x = _v27
          start = end
          end += 32
          (_x.x, _x.y, _x.z, _x.w,) = _get_struct_4d().unpack(str[start:end])
          start = end
          end += 72
          _v24.orientation_covariance = _get_struct_9d().unpack(str[start:end])
          _v28 = _v24.angular_velocity
          _x = _v28
          start = end
          end += 24
          (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
          start = end
          end += 72
          _v24.angular_velocity_covariance = _get_struct_9d().unpack(str[start:end])
          _v29 = _v24.linear_acceleration
          _x = _v29
          start = end
          end += 24
          (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
          start = end
          end += 72
          _v24.linear_acceleration_covariance = _get_struct_9d().unpack(str[start:end])
          _v30 = _v23.magnetic_field
          _x = _v30
          start = end
          end += 24
          (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
          _x = _v23
          start = end
          end += 9
          (_x.roll, _x.pitch, _x.deviceCalibrated,) = _get_struct_2fB().unpack(str[start:end])
          _v23.deviceCalibrated = bool(_v23.deviceCalibrated)
          _v17.sensors.append(val3)
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        val1.settings = []
        for i in range(0, length):
          val2 = digitaleye_msgs.msg.Metric()
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            val2.name = str[start:end].decode('utf-8', 'rosmsg')
          else:
            val2.name = str[start:end]
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            val2.value = str[start:end].decode('utf-8', 'rosmsg')
          else:
            val2.value = str[start:end]
          val1.settings.append(val2)
        self.poles.append(val1)
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      length = len(self.poles)
      buff.write(_struct_I.pack(length))
      for val1 in self.poles:
        _x = val1.id
        buff.write(_get_struct_I().pack(_x))
        _x = val1.ip_address
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        _x = val1.mvc
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        _x = val1.iot
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        _x = val1.position_frame
        buff.write(_get_struct_I().pack(_x))
        _v31 = val1.position
        _x = _v31
        buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
        _x = val1
        buff.write(_get_struct_I2f().pack(_x.orientation_frame, _x.orientation, _x.height))
        _v32 = val1.state
        _v33 = _v32.component
        _x = _v33
        buff.write(_get_struct_3I().pack(_x.id, _x.state, _x.status))
        _x = _v33.description
        length = len(_x)
        if python3 or type(_x) == unicode:
          _x = _x.encode('utf-8')
          length = len(_x)
        buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        _x = _v33.lastChange
        buff.write(_get_struct_I().pack(_x))
        length = len(_v33.metrics)
        buff.write(_struct_I.pack(length))
        for val4 in _v33.metrics:
          _x = val4.name
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _x = val4.value
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
        length = len(_v32.sensors)
        buff.write(_struct_I.pack(length))
        for val3 in _v32.sensors:
          _x = val3.sensor_id
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _x = val3.model
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _x = val3.type
          buff.write(_get_struct_I().pack(_x))
          _v34 = val3.pose
          _v35 = _v34.position
          _x = _v35
          buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
          _v36 = _v34.orientation
          _x = _v36
          buff.write(_get_struct_4d().pack(_x.x, _x.y, _x.z, _x.w))
          _x = val3
          buff.write(_get_struct_f3IfB().pack(_x.azimuth, _x.image_width, _x.image_height, _x.frame_rate, _x.power, _x.calibrated))
          _v37 = val3.state
          _x = _v37
          buff.write(_get_struct_3I().pack(_x.id, _x.state, _x.status))
          _x = _v37.description
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _x = _v37.lastChange
          buff.write(_get_struct_I().pack(_x))
          length = len(_v37.metrics)
          buff.write(_struct_I.pack(length))
          for val5 in _v37.metrics:
            _x = val5.name
            length = len(_x)
            if python3 or type(_x) == unicode:
              _x = _x.encode('utf-8')
              length = len(_x)
            buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
            _x = val5.value
            length = len(_x)
            if python3 or type(_x) == unicode:
              _x = _x.encode('utf-8')
              length = len(_x)
            buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _v38 = val3.imu
          _x = _v38.heading
          buff.write(_get_struct_f().pack(_x))
          _x = _v38.device_id
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _v39 = _v38.imu
          _v40 = _v39.header
          _x = _v40.seq
          buff.write(_get_struct_I().pack(_x))
          _v41 = _v40.stamp
          _x = _v41
          buff.write(_get_struct_2I().pack(_x.secs, _x.nsecs))
          _x = _v40.frame_id
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _v42 = _v39.orientation
          _x = _v42
          buff.write(_get_struct_4d().pack(_x.x, _x.y, _x.z, _x.w))
          buff.write(_v39.orientation_covariance.tostring())
          _v43 = _v39.angular_velocity
          _x = _v43
          buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
          buff.write(_v39.angular_velocity_covariance.tostring())
          _v44 = _v39.linear_acceleration
          _x = _v44
          buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
          buff.write(_v39.linear_acceleration_covariance.tostring())
          _v45 = _v38.magnetic_field
          _x = _v45
          buff.write(_get_struct_3d().pack(_x.x, _x.y, _x.z))
          _x = _v38
          buff.write(_get_struct_2fB().pack(_x.roll, _x.pitch, _x.deviceCalibrated))
        length = len(val1.settings)
        buff.write(_struct_I.pack(length))
        for val2 in val1.settings:
          _x = val2.name
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
          _x = val2.value
          length = len(_x)
          if python3 or type(_x) == unicode:
            _x = _x.encode('utf-8')
            length = len(_x)
          buff.write(struct.Struct('<I%ss'%length).pack(length, _x))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.poles is None:
        self.poles = None
      end = 0
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.poles = []
      for i in range(0, length):
        val1 = digitaleye_msgs.msg.Pole()
        start = end
        end += 4
        (val1.id,) = _get_struct_I().unpack(str[start:end])
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          val1.ip_address = str[start:end].decode('utf-8', 'rosmsg')
        else:
          val1.ip_address = str[start:end]
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          val1.mvc = str[start:end].decode('utf-8', 'rosmsg')
        else:
          val1.mvc = str[start:end]
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          val1.iot = str[start:end].decode('utf-8', 'rosmsg')
        else:
          val1.iot = str[start:end]
        start = end
        end += 4
        (val1.position_frame,) = _get_struct_I().unpack(str[start:end])
        _v46 = val1.position
        _x = _v46
        start = end
        end += 24
        (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
        _x = val1
        start = end
        end += 12
        (_x.orientation_frame, _x.orientation, _x.height,) = _get_struct_I2f().unpack(str[start:end])
        _v47 = val1.state
        _v48 = _v47.component
        _x = _v48
        start = end
        end += 12
        (_x.id, _x.state, _x.status,) = _get_struct_3I().unpack(str[start:end])
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        start = end
        end += length
        if python3:
          _v48.description = str[start:end].decode('utf-8', 'rosmsg')
        else:
          _v48.description = str[start:end]
        start = end
        end += 4
        (_v48.lastChange,) = _get_struct_I().unpack(str[start:end])
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        _v48.metrics = []
        for i in range(0, length):
          val4 = digitaleye_msgs.msg.Metric()
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            val4.name = str[start:end].decode('utf-8', 'rosmsg')
          else:
            val4.name = str[start:end]
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            val4.value = str[start:end].decode('utf-8', 'rosmsg')
          else:
            val4.value = str[start:end]
          _v48.metrics.append(val4)
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        _v47.sensors = []
        for i in range(0, length):
          val3 = digitaleye_msgs.msg.Sensor()
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            val3.sensor_id = str[start:end].decode('utf-8', 'rosmsg')
          else:
            val3.sensor_id = str[start:end]
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            val3.model = str[start:end].decode('utf-8', 'rosmsg')
          else:
            val3.model = str[start:end]
          start = end
          end += 4
          (val3.type,) = _get_struct_I().unpack(str[start:end])
          _v49 = val3.pose
          _v50 = _v49.position
          _x = _v50
          start = end
          end += 24
          (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
          _v51 = _v49.orientation
          _x = _v51
          start = end
          end += 32
          (_x.x, _x.y, _x.z, _x.w,) = _get_struct_4d().unpack(str[start:end])
          _x = val3
          start = end
          end += 21
          (_x.azimuth, _x.image_width, _x.image_height, _x.frame_rate, _x.power, _x.calibrated,) = _get_struct_f3IfB().unpack(str[start:end])
          val3.calibrated = bool(val3.calibrated)
          _v52 = val3.state
          _x = _v52
          start = end
          end += 12
          (_x.id, _x.state, _x.status,) = _get_struct_3I().unpack(str[start:end])
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            _v52.description = str[start:end].decode('utf-8', 'rosmsg')
          else:
            _v52.description = str[start:end]
          start = end
          end += 4
          (_v52.lastChange,) = _get_struct_I().unpack(str[start:end])
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          _v52.metrics = []
          for i in range(0, length):
            val5 = digitaleye_msgs.msg.Metric()
            start = end
            end += 4
            (length,) = _struct_I.unpack(str[start:end])
            start = end
            end += length
            if python3:
              val5.name = str[start:end].decode('utf-8', 'rosmsg')
            else:
              val5.name = str[start:end]
            start = end
            end += 4
            (length,) = _struct_I.unpack(str[start:end])
            start = end
            end += length
            if python3:
              val5.value = str[start:end].decode('utf-8', 'rosmsg')
            else:
              val5.value = str[start:end]
            _v52.metrics.append(val5)
          _v53 = val3.imu
          start = end
          end += 4
          (_v53.heading,) = _get_struct_f().unpack(str[start:end])
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            _v53.device_id = str[start:end].decode('utf-8', 'rosmsg')
          else:
            _v53.device_id = str[start:end]
          _v54 = _v53.imu
          _v55 = _v54.header
          start = end
          end += 4
          (_v55.seq,) = _get_struct_I().unpack(str[start:end])
          _v56 = _v55.stamp
          _x = _v56
          start = end
          end += 8
          (_x.secs, _x.nsecs,) = _get_struct_2I().unpack(str[start:end])
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            _v55.frame_id = str[start:end].decode('utf-8', 'rosmsg')
          else:
            _v55.frame_id = str[start:end]
          _v57 = _v54.orientation
          _x = _v57
          start = end
          end += 32
          (_x.x, _x.y, _x.z, _x.w,) = _get_struct_4d().unpack(str[start:end])
          start = end
          end += 72
          _v54.orientation_covariance = numpy.frombuffer(str[start:end], dtype=numpy.float64, count=9)
          _v58 = _v54.angular_velocity
          _x = _v58
          start = end
          end += 24
          (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
          start = end
          end += 72
          _v54.angular_velocity_covariance = numpy.frombuffer(str[start:end], dtype=numpy.float64, count=9)
          _v59 = _v54.linear_acceleration
          _x = _v59
          start = end
          end += 24
          (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
          start = end
          end += 72
          _v54.linear_acceleration_covariance = numpy.frombuffer(str[start:end], dtype=numpy.float64, count=9)
          _v60 = _v53.magnetic_field
          _x = _v60
          start = end
          end += 24
          (_x.x, _x.y, _x.z,) = _get_struct_3d().unpack(str[start:end])
          _x = _v53
          start = end
          end += 9
          (_x.roll, _x.pitch, _x.deviceCalibrated,) = _get_struct_2fB().unpack(str[start:end])
          _v53.deviceCalibrated = bool(_v53.deviceCalibrated)
          _v47.sensors.append(val3)
        start = end
        end += 4
        (length,) = _struct_I.unpack(str[start:end])
        val1.settings = []
        for i in range(0, length):
          val2 = digitaleye_msgs.msg.Metric()
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            val2.name = str[start:end].decode('utf-8', 'rosmsg')
          else:
            val2.name = str[start:end]
          start = end
          end += 4
          (length,) = _struct_I.unpack(str[start:end])
          start = end
          end += length
          if python3:
            val2.value = str[start:end].decode('utf-8', 'rosmsg')
          else:
            val2.value = str[start:end]
          val1.settings.append(val2)
        self.poles.append(val1)
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
_struct_2I = None
def _get_struct_2I():
    global _struct_2I
    if _struct_2I is None:
        _struct_2I = struct.Struct("<2I")
    return _struct_2I
_struct_2fB = None
def _get_struct_2fB():
    global _struct_2fB
    if _struct_2fB is None:
        _struct_2fB = struct.Struct("<2fB")
    return _struct_2fB
_struct_3I = None
def _get_struct_3I():
    global _struct_3I
    if _struct_3I is None:
        _struct_3I = struct.Struct("<3I")
    return _struct_3I
_struct_3d = None
def _get_struct_3d():
    global _struct_3d
    if _struct_3d is None:
        _struct_3d = struct.Struct("<3d")
    return _struct_3d
_struct_4d = None
def _get_struct_4d():
    global _struct_4d
    if _struct_4d is None:
        _struct_4d = struct.Struct("<4d")
    return _struct_4d
_struct_9d = None
def _get_struct_9d():
    global _struct_9d
    if _struct_9d is None:
        _struct_9d = struct.Struct("<9d")
    return _struct_9d
_struct_I2f = None
def _get_struct_I2f():
    global _struct_I2f
    if _struct_I2f is None:
        _struct_I2f = struct.Struct("<I2f")
    return _struct_I2f
_struct_f = None
def _get_struct_f():
    global _struct_f
    if _struct_f is None:
        _struct_f = struct.Struct("<f")
    return _struct_f
_struct_f3IfB = None
def _get_struct_f3IfB():
    global _struct_f3IfB
    if _struct_f3IfB is None:
        _struct_f3IfB = struct.Struct("<f3IfB")
    return _struct_f3IfB



from ._GetEntrypoint import *
from ._GetFlightpath import *
from ._GetMGSObjects import *
from ._GetMGSStatus import *
from ._GetNotifications import *
from ._GetPoles import *
from ._GetSchedule import *
from ._GetStatus import *
from ._GetUAVExternalReport import *
from ._GetUAVInternalReport import *
from ._GetUavIdInt import *
from ._GetUavIdString import *
from ._PointConversion import *



# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/GetScheduleRequest.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct


class GetScheduleRequest(genpy.Message):
  _md5sum = "d767b3ad20ae4020fcbe6daefd388da5"
  _type = "digitaleye_msgs/GetScheduleRequest"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """# Returns a list of zones to which an IOT tag has been granted
# access during the specified time window

# unique identifier of the IOT tag for which to return permission grants
uint64 tag_id

# beginning of the time window for which to return permission grants
# (Epoch timestamp in seconds)
uint32 start

# end of the time window for which to return permission grants
# (Epoch timestamp in seconds)
uint32 end

"""
  __slots__ = ['tag_id','start','end']
  _slot_types = ['uint64','uint32','uint32']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       tag_id,start,end

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(GetScheduleRequest, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.tag_id is None:
        self.tag_id = 0
      if self.start is None:
        self.start = 0
      if self.end is None:
        self.end = 0
    else:
      self.tag_id = 0
      self.start = 0
      self.end = 0

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      _x = self
      buff.write(_get_struct_Q2I().pack(_x.tag_id, _x.start, _x.end))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      end = 0
      _x = self
      start = end
      end += 16
      (_x.tag_id, _x.start, _x.end,) = _get_struct_Q2I().unpack(str[start:end])
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      _x = self
      buff.write(_get_struct_Q2I().pack(_x.tag_id, _x.start, _x.end))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      end = 0
      _x = self
      start = end
      end += 16
      (_x.tag_id, _x.start, _x.end,) = _get_struct_Q2I().unpack(str[start:end])
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
_struct_Q2I = None
def _get_struct_Q2I():
    global _struct_Q2I
    if _struct_Q2I is None:
        _struct_Q2I = struct.Struct("<Q2I")
    return _struct_Q2I
# This Python file uses the following encoding: utf-8
"""autogenerated by genpy from digitaleye_msgs/GetScheduleResponse.msg. Do not edit."""
import codecs
import sys
python3 = True if sys.hexversion > 0x03000000 else False
import genpy
import struct

import digitaleye_msgs.msg

class GetScheduleResponse(genpy.Message):
  _md5sum = "7424d12ed06d7bc9e3ecccf1bc7ec2a5"
  _type = "digitaleye_msgs/GetScheduleResponse"
  _has_header = False  # flag to mark the presence of a Header object
  _full_text = """
# permission grants
digitaleye_msgs/AccessSchedule schedule


================================================================================
MSG: digitaleye_msgs/AccessSchedule
# List of authorisations for an object

# id of the object
uint64 object_id

# list of authorisation(s)
digitaleye_msgs/TimeSlot[] schedule

================================================================================
MSG: digitaleye_msgs/TimeSlot
# Zone authorisation

# TOLZ to which access has been granted
uint32 zone_id

# start time of authorisation (included) (Epoch timestamp in seconds)
uint32 start

# end time of authorisation (included) (Epoch timestamp in seconds)
uint32 end
"""
  __slots__ = ['schedule']
  _slot_types = ['digitaleye_msgs/AccessSchedule']

  def __init__(self, *args, **kwds):
    """
    Constructor. Any message fields that are implicitly/explicitly
    set to None will be assigned a default value. The recommend
    use is keyword arguments as this is more robust to future message
    changes.  You cannot mix in-order arguments and keyword arguments.

    The available fields are:
       schedule

    :param args: complete set of field values, in .msg order
    :param kwds: use keyword arguments corresponding to message field names
    to set specific fields.
    """
    if args or kwds:
      super(GetScheduleResponse, self).__init__(*args, **kwds)
      # message fields cannot be None, assign default values for those that are
      if self.schedule is None:
        self.schedule = digitaleye_msgs.msg.AccessSchedule()
    else:
      self.schedule = digitaleye_msgs.msg.AccessSchedule()

  def _get_types(self):
    """
    internal API method
    """
    return self._slot_types

  def serialize(self, buff):
    """
    serialize message into buffer
    :param buff: buffer, ``StringIO``
    """
    try:
      _x = self.schedule.object_id
      buff.write(_get_struct_Q().pack(_x))
      length = len(self.schedule.schedule)
      buff.write(_struct_I.pack(length))
      for val1 in self.schedule.schedule:
        _x = val1
        buff.write(_get_struct_3I().pack(_x.zone_id, _x.start, _x.end))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize(self, str):
    """
    unpack serialized message in str into this message instance
    :param str: byte array of serialized message, ``str``
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.schedule is None:
        self.schedule = digitaleye_msgs.msg.AccessSchedule()
      end = 0
      start = end
      end += 8
      (self.schedule.object_id,) = _get_struct_Q().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.schedule.schedule = []
      for i in range(0, length):
        val1 = digitaleye_msgs.msg.TimeSlot()
        _x = val1
        start = end
        end += 12
        (_x.zone_id, _x.start, _x.end,) = _get_struct_3I().unpack(str[start:end])
        self.schedule.schedule.append(val1)
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill


  def serialize_numpy(self, buff, numpy):
    """
    serialize message with numpy array types into buffer
    :param buff: buffer, ``StringIO``
    :param numpy: numpy python module
    """
    try:
      _x = self.schedule.object_id
      buff.write(_get_struct_Q().pack(_x))
      length = len(self.schedule.schedule)
      buff.write(_struct_I.pack(length))
      for val1 in self.schedule.schedule:
        _x = val1
        buff.write(_get_struct_3I().pack(_x.zone_id, _x.start, _x.end))
    except struct.error as se: self._check_types(struct.error("%s: '%s' when writing '%s'" % (type(se), str(se), str(locals().get('_x', self)))))
    except TypeError as te: self._check_types(ValueError("%s: '%s' when writing '%s'" % (type(te), str(te), str(locals().get('_x', self)))))

  def deserialize_numpy(self, str, numpy):
    """
    unpack serialized message in str into this message instance using numpy for array types
    :param str: byte array of serialized message, ``str``
    :param numpy: numpy python module
    """
    if python3:
      codecs.lookup_error("rosmsg").msg_type = self._type
    try:
      if self.schedule is None:
        self.schedule = digitaleye_msgs.msg.AccessSchedule()
      end = 0
      start = end
      end += 8
      (self.schedule.object_id,) = _get_struct_Q().unpack(str[start:end])
      start = end
      end += 4
      (length,) = _struct_I.unpack(str[start:end])
      self.schedule.schedule = []
      for i in range(0, length):
        val1 = digitaleye_msgs.msg.TimeSlot()
        _x = val1
        start = end
        end += 12
        (_x.zone_id, _x.start, _x.end,) = _get_struct_3I().unpack(str[start:end])
        self.schedule.schedule.append(val1)
      return self
    except struct.error as e:
      raise genpy.DeserializationError(e)  # most likely buffer underfill

_struct_I = genpy.struct_I
def _get_struct_I():
    global _struct_I
    return _struct_I
_struct_3I = None
def _get_struct_3I():
    global _struct_3I
    if _struct_3I is None:
        _struct_3I = struct.Struct("<3I")
    return _struct_3I
_struct_Q = None
def _get_struct_Q():
    global _struct_Q
    if _struct_Q is None:
        _struct_Q = struct.Struct("<Q")
    return _struct_Q
class GetSchedule(object):
  _type          = 'digitaleye_msgs/GetSchedule'
  _md5sum = 'c9d090f422f7f08dd94c94be5bb64ff8'
  _request_class  = GetScheduleRequest
  _response_class = GetScheduleResponse
